@@ -41,7 +41,7 @@
 #include "util.h"
 
 /* users of this template also need assert() */
-#include "assert.h"
+#include "compat/assert.h"
 
 /* iterator support */
 
@@ -109,6 +109,7 @@ public:
     iterator end();
     const_iterator end () const;
     E& operator [] (unsigned i);
+    const E& operator [] (unsigned i) const;
 
     /* Do not change these, until the entry C struct is removed */
     size_t capacity;
@@ -346,6 +347,14 @@ Vector<E>::operator [] (unsigned i)
     return items[i];
 }
 
+template<class E>
+const E &
+Vector<E>::operator [] (unsigned i) const
+{
+    assert (size() > i);
+    return items[i];
+}
+
 template<class C>
 VectorIteratorBase<C>::VectorIteratorBase() : pos(0), theVector(NULL)
 {}
