@@ -1,8 +1,8 @@
 
 /*
- * $Id: multicast.cc,v 1.13 2007/12/14 23:11:47 amosjeffries Exp $
+ * $Id$
  *
- * DEBUG: section 7     Multicast
+ * DEBUG: section 07    Multicast
  * AUTHOR: Martin Hamilton
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -50,7 +50,7 @@ mcastSetTtl(int fd, int mcast_ttl)
 }
 
 void
-mcastJoinGroups(const ipcache_addrs * ia, void *datanotused)
+mcastJoinGroups(const ipcache_addrs *ia, const DnsLookupDetails &, void *datanotused)
 {
 #ifdef IP_MULTICAST_TTL
     int fd = theInIcpConnection;
